pub fn try_decode(buf: &[u8]) -> Option<ProtocolMessage>Expand description
Attempt to decode a message, returning None when parsing fails.
pub fn try_decode(buf: &[u8]) -> Option<ProtocolMessage>Attempt to decode a message, returning None when parsing fails.